Motor GridFS Classes
====================

.. currentmodule:: motor.motor_tornado

Store blobs of data in `GridFS <http://dochub.mongodb.org/core/gridfs>`_.

.. seealso:: :ref:`Differences between PyMongo's and Motor's GridFS APIs
  <gridfs-differences>`.

.. seealso:: :doc:`web`

.. autoclass:: MotorGridFS
  :members:

.. autoclass:: MotorGridIn
  :members:

.. autoclass:: MotorGridOut
  :members:

.. autoclass:: MotorGridOutCursor
  :members:
